@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/local/bin/python2.7
 # -*- encoding: utf-8; py-indent-offset: 4 -*-
 # +------------------------------------------------------------------+
 # |             ____ _               _        __  __ _  __           |
@@ -55,6 +55,9 @@ class MultisiteServer(GenericServer):
         self.urls = {}
         self.statemap = {}
         
+        # Entries for monitor default actions in context menu
+        self.MENU_ACTIONS = ["Recheck", "Acknowledge", "Downtime"]
+        
 
     def init_HTTP(self):
         # Fix eventually missing tailing "/" in url
@@ -97,7 +100,8 @@ class MultisiteServer(GenericServer):
         content, error = result.result, result.error
 
         if error != "":
-            raise MultisiteError(True, Result(result = copy.deepcopy(content), error = error))
+            #raise MultisiteError(True, Result(result = copy.deepcopy(content), error = error))
+            raise MultisiteError(True, Result(result = content, error = error))
 
         if content.startswith('WARNING:'):
             c = content.split("\n")
@@ -127,31 +131,13 @@ class MultisiteServer(GenericServer):
 
         # Create URLs for the configured filters
         url_params = ''
-        if str(self.conf.filter_all_down_hosts) == "True":
-            url_params += '&hst1=0'
-        if str(self.conf.filter_all_unreachable_hosts) == "True":
-            url_params += '&hst2=0'
 
-        if str(self.conf.filter_all_unknown_services) == "True":
-            url_params += '&st3=0'
-        if str(self.conf.filter_all_critical_services) == "True":
-            url_params += '&st2=0'
-        if str(self.conf.filter_all_warning_services) == "True":
-            url_params += '&st1=0'
-
-        # Hide all acked hosts/services
-        if str(self.conf.filter_acknowledged_hosts_services) == "True":
-            url_params += '&is_host_acknowledged=0&is_service_acknowledged=0'
-        # Hide all hosts/services with disabled notifications
-        if str(self.conf.filter_hosts_services_disabled_notifications) == "True":
-            url_params += '&is_host_notifications_enabled=1&is_service_notifications_enabled=1'
-        # Hide all hosts/services with disabled checks
-        if str(self.conf.filter_hosts_services_disabled_checks) == "True":
-            url_params += '&is_host_active_checks_enabled=1&is_service_active_checks_enabled=1'
-        # Hide all hosts/services in downtime
-        if str(self.conf.filter_hosts_services_maintenance) == "True":
-            url_params += '&host_scheduled_downtime_depth=0&is_in_downtime=0'
+        url_params += '&is_host_acknowledged=-1&is_service_acknowledged=-1'
+        url_params += '&is_host_notifications_enabled=-1&is_service_notifications_enabled=-1'
+        url_params += '&is_host_active_checks_enabled=-1&is_service_active_checks_enabled=-1'
+        url_params += '&host_scheduled_downtime_depth=-1&is_in_downtime=-1'
 
+        
         try:
             response = []
             try:
@@ -161,7 +147,7 @@ class MultisiteServer(GenericServer):
                     return e.result
 
             for row in response[1:]:
-                host= dict(zip(response[0], row))
+                host= dict(zip(response[0], row))               
                 n = {
                     'host':               host['host'],
                     'status':             self.statemap.get(host['host_state'], host['host_state']),
@@ -173,12 +159,6 @@ class MultisiteServer(GenericServer):
                     'address':            host['host_address'],
                 }
 
-                if host['host_in_downtime'] == 'yes':
-                    self.new_hosts_in_maintenance.append(host['host'])
-
-                if host['host_acknowledged'] == 'yes':
-                    self.new_hosts_acknowledged.append(host['host'])
-
                 # add dictionary full of information about this host item to nagitems
                 nagitems["hosts"].append(n)
                 # after collection data in nagitems create objects from its informations
@@ -194,7 +174,14 @@ class MultisiteServer(GenericServer):
                     self.new_hosts[new_host].status_information= n["status_information"]
                     self.new_hosts[new_host].site    = n["site"]
                     self.new_hosts[new_host].address = n["address"]
-
+                    # transisition to Check_MK 1.1.10p2
+                    if host.has_key('host_in_downtime'):
+                        if host['host_in_downtime'] == 'yes':
+                            self.new_hosts[new_host].scheduled_downtime = True
+                    if host.has_key('host_acknowledged'):
+                        if host['host_acknowledged'] == 'yes':
+                            self.new_hosts[new_host].acknowledged = True
+                        
         except:
             self.isChecking = False
             result, error = self.Error(sys.exc_info())
@@ -216,11 +203,10 @@ class MultisiteServer(GenericServer):
                     return e.result
                 else:
                     response = e.result.content
-                    ret = e.result
-
+                    ret = e.result   
+                    
             for row in response[1:]:
                 service = dict(zip(response[0], row))
-
                 n = {
                     'host':               service['host'],
                     'service':            service['service_description'],
@@ -231,7 +217,7 @@ class MultisiteServer(GenericServer):
                     'status_information': service['svc_plugin_output'],
                     # Check_MK passive services can be re-scheduled by using the Check_MK service
                     'passiveonly':        service['svc_is_active'] == 'no' and not service['svc_check_command'].startswith('check_mk'),
-                    'notifications':      service['svc_flapping'] == 'yes',
+                    'notifications':      service['svc_notifications_enabled'] == 'yes',
                     'flapping':           service['svc_flapping'] == 'yes',
                     'site':               service['sitename_plain'],
                     'address':            service['host_address'],
@@ -260,9 +246,23 @@ class MultisiteServer(GenericServer):
                     self.new_hosts[n["host"]].services[new_service].attempt = n["attempt"]
                     self.new_hosts[n["host"]].services[new_service].status_information = n["status_information"]
                     self.new_hosts[n["host"]].services[new_service].passiveonly = n["passiveonly"]
+                    self.new_hosts[n["host"]].services[new_service].flapping = n["flapping"]                    
                     self.new_hosts[n["host"]].services[new_service].site = n["site"]
                     self.new_hosts[n["host"]].services[new_service].address = n["address"]
                     self.new_hosts[n["host"]].services[new_service].command = n["command"]
+                    # transisition to Check_MK 1.1.10p2
+                    if service.has_key('svc_in_downtime'):
+                        if service['svc_in_downtime'] == 'yes':
+                            self.new_hosts[n["host"]].services[new_service].scheduled_downtime = True
+                    if service.has_key('svc_acknowledged'):
+                        if service['svc_acknowledged'] == 'yes':
+                            self.new_hosts[n["host"]].services[new_service].acknowledged = True
+                    if service.has_key('svc_is_active'):
+                        if service['svc_is_active'] == 'no':
+                            self.new_hosts[n["host"]].services[new_service].passiveonly = True
+                    if service.has_key('svc_flapping'):
+                        if service['svc_flapping'] == 'yes':
+                            self.new_hosts[n["host"]].services[new_service].flapping = True
         except:
             # set checking flag back to False
             self.isChecking = False
@@ -304,8 +304,13 @@ class MultisiteServer(GenericServer):
         find out ip or hostname of given host to access hosts/devices which do not appear in DNS but
         have their ip saved in Nagios
         """
+        
+        # the fasted method is taking hostname as used in monitor
+        if str(self.conf.connect_by_host) == "True":
+            return Result(result=host)
 
         ip = ""
+
         try:
             if host in self.hosts:
                 ip = self.hosts[host].address
@@ -313,7 +318,7 @@ class MultisiteServer(GenericServer):
             if str(self.conf.debug_mode) == "True":
                 self.Debug(server=self.get_name(), host=host, debug ="IP of %s:" % (host) + " " + ip)
 
-            if str(self.conf.connect_by_dns_yes) == "True":
+            if str(self.conf.connect_by_dns) == "True":
                 try:
                     address = socket.gethostbyaddr(ip)[0]
                 except:
